@@ -2,7 +2,8 @@
 # distance data
 import cv2
 import numpy as np
-#from ..Classes.EntityLayer import EntityLayer
+from ..Classes.EntityLayer import EntityLayer
+
 
 def circleAndRectangleDetection():
     """
@@ -94,7 +95,10 @@ def circleAndRectangleDetection():
 
 
 # sample usage
-#imageObject = EntityLayer((25, 15), "rectangle", 12, "trapezium")
-#print(imageObject.getBoundingBoxes())
+
+imageObject = EntityLayer((25, 15), "rectangle", 12, "trapezium")
+print(imageObject.getBoundingBoxes())
+
+
 print("Goruntu isleme metodu calistirildi...")
 # circleAndRectangleDetection()
